Package: quarto
Title: R Interface to 'Quarto' Markdown Publishing System
Version: 1.4.4
Authors@R: c(
    person("JJ", "Allaire", , "jj@posit.co", role = "aut",
           comment = c(ORCID = "0000-0003-0174-9868")),
    person("Christophe", "Dervieux", , "cderv@posit.co", role = c("cre", "aut"),
           comment = c(ORCID = "0000-0003-4474-2498")),
    person("Posit Software, PBC", role = c("cph", "fnd"))
  )
Description: Convert R Markdown documents and 'Jupyter' notebooks to a
    variety of output formats using 'Quarto'.
License: GPL (>= 2)
URL: https://github.com/quarto-dev/quarto-r,
        https://quarto-dev.github.io/quarto-r/
BugReports: https://github.com/quarto-dev/quarto-r/issues
Depends: R (>= 3.6)
Imports: cli, jsonlite, later, processx, rlang, rmarkdown, rstudioapi,
        tools, utils, yaml
Suggests: curl, knitr, rsconnect (>= 0.8.26), testthat (>= 3.1.7),
        withr, xfun
VignetteBuilder: quarto
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.2
SystemRequirements: Quarto command line tool
        (<https://github.com/quarto-dev/quarto-cli>).
NeedsCompilation: no
Packaged: 2024-07-19 17:48:41 UTC; chris
Author: JJ Allaire [aut] (<https://orcid.org/0000-0003-0174-9868>),
  Christophe Dervieux [cre, aut]
    (<https://orcid.org/0000-0003-4474-2498>),
  Posit Software, PBC [cph, fnd]
Maintainer: Christophe Dervieux <cderv@posit.co>
Repository: CRAN
Date/Publication: 2024-07-20 06:20:01 UTC
Built: R 4.4.1; ; 2024-07-21 20:59:13 UTC; unix
