test_that("Installing an extension", {
  skip_if_no_quarto()
  skip_if_offline("github.com")
  dir <- withr::local_tempdir()
  withr::local_dir(dir)
  expect_error(quarto_use_template("quarto-journals/jss"), "explicit approval")
  quarto_use_template("quarto-journals/jss", no_prompt = TRUE, quiet = TRUE)
  expect_true(dir.exists("_extensions/quarto-journals/jss"))
  expect_length(list.files(pattern = "[.]qmd$"), 1)
})
